@@ -2,9 +2,14 @@ from pkg_resources import get_distribution
 
 from .double_ml_plr import DoubleMLPLR
 from .double_ml_pliv import DoubleMLPLIV
-#from .double_ml_pliv_partial_z import DoubleMLPLIVselectZ
 from .double_ml_irm import DoubleMLIRM
 from .double_ml_iivm import DoubleMLIIVM
 from .double_ml_data import DoubleMLData
 
+__all__ = ['DoubleMLPLR',
+           'DoubleMLPLIV',
+           'DoubleMLIRM',
+           'DoubleMLIIVM',
+           'DoubleMLData']
+
 __version__ = get_distribution('doubleml').version
