@@ -4,7 +4,7 @@ import io
 
 from sklearn.utils.validation import check_array, column_or_1d,  check_consistent_length
 from sklearn.utils.multiclass import type_of_target
-from ._helper import _assure_2d_array
+from ._utils import _assure_2d_array
 
 
 class DoubleMLData:
@@ -56,12 +56,19 @@ class DoubleMLData:
                  x_cols=None,
                  z_cols=None,
                  use_other_treat_as_covariate=True):
+        if not isinstance(data, pd.DataFrame):
+            raise TypeError('data must be of pd.DataFrame type. '
+                            f'{str(data)} of type {str(type(data))} was passed.')
+        if not data.columns.is_unique:
+            raise ValueError('Invalid pd.DataFrame: '
+                             'Contains duplicate column names.')
         self._data = data
 
         self.y_col = y_col
         self.d_cols = d_cols
         self.z_cols = z_cols
         self.x_cols = x_cols
+        self._check_disjoint_sets()
         self.use_other_treat_as_covariate = use_other_treat_as_covariate
         self._binary_treats = self._check_binary_treats()
         self._set_y_z()
@@ -69,15 +76,18 @@ class DoubleMLData:
         self.set_x_d(self.d_cols[0])
 
     def __str__(self):
+        data_info = f'Outcome variable: {self.y_col}\n' \
+                    f'Treatment variable(s): {self.d_cols}\n' \
+                    f'Covariates: {self.x_cols}\n' \
+                    f'Instrument variable(s): {self.z_cols}\n' \
+                    f'No. Observations: {self.n_obs}\n'
         buf = io.StringIO()
         self.data.info(verbose=False, buf=buf)
-        data_info = buf.getvalue()
-        return f'=== DoubleMLData Object ===\n' \
-               f'y_col: {self.y_col}\n' \
-               f'd_cols: {self.d_cols}\n' \
-               f'x_cols: {self.x_cols}\n' \
-               f'z_cols: {self.z_cols}\n' \
-               f'data:\n {data_info}'
+        df_info = buf.getvalue()
+        res = '================== DoubleMLData Object ==================\n' + \
+              '\n------------------ Data summary      ------------------\n' + data_info + \
+              '\n------------------ DataFrame info    ------------------\n' + df_info
+        return res
 
     @classmethod
     def from_arrays(cls, x, y, d, z=None, use_other_treat_as_covariate=True):
@@ -245,6 +255,9 @@ class DoubleMLData:
             if not isinstance(value, list):
                 raise TypeError('The covariates x_cols must be of str or list type (or None). '
                                 f'{str(value)} of type {str(type(value))} was passed.')
+            if not len(set(value)) == len(value):
+                raise ValueError('Invalid covariates x_cols: '
+                                 'Contains duplicate values.')
             if not set(value).issubset(set(self.all_variables)):
                 raise ValueError('Invalid covariates x_cols. '
                                  'At least one covariate is no data column.')
@@ -253,13 +266,14 @@ class DoubleMLData:
         else:
             # x_cols defaults to all columns but y_col, d_cols and z_cols
             if self.z_cols is not None:
-                y_d_z = set.union(set(self.y_col), set(self.d_cols), set(self.z_cols))
+                y_d_z = set.union({self.y_col}, set(self.d_cols), set(self.z_cols))
                 x_cols = [col for col in self.data.columns if col not in y_d_z]
             else:
-                y_d = set.union(set(self.y_col), set(self.d_cols))
+                y_d = set.union({self.y_col}, set(self.d_cols))
                 x_cols = [col for col in self.data.columns if col not in y_d]
             self._x_cols = x_cols
         if reset_value:
+            self._check_disjoint_sets()
             # by default, we initialize to the first treatment variable
             self.set_x_d(self.d_cols[0])
 
@@ -278,11 +292,15 @@ class DoubleMLData:
         if not isinstance(value, list):
             raise TypeError('The treatment variable(s) d_cols must be of str or list type. '
                             f'{str(value)} of type {str(type(value))} was passed.')
+        if not len(set(value)) == len(value):
+            raise ValueError('Invalid treatment variable(s) d_cols: '
+                             'Contains duplicate values.')
         if not set(value).issubset(set(self.all_variables)):
             raise ValueError('Invalid treatment variable(s) d_cols. '
                              'At least one treatment variable is no data column.')
         self._d_cols = value
         if reset_value:
+            self._check_disjoint_sets()
             # by default, we initialize to the first treatment variable
             self.set_x_d(self.d_cols[0])
 
@@ -304,6 +322,7 @@ class DoubleMLData:
                              f'{value} is no data column.')
         self._y_col = value
         if reset_value:
+            self._check_disjoint_sets()
             self._set_y_z()
 
     @property
@@ -322,6 +341,9 @@ class DoubleMLData:
             if not isinstance(value, list):
                 raise TypeError('The instrumental variable(s) z_cols must be of str or list type (or None). '
                                 f'{str(value)} of type {str(type(value))} was passed.')
+            if not len(set(value)) == len(value):
+                raise ValueError('Invalid instrumental variable(s) z_cols: '
+                                 'Contains duplicate values.')
             if not set(value).issubset(set(self.all_variables)):
                 raise ValueError('Invalid instrumental variable(s) z_cols. '
                                  'At least one instrumental variable is no data column.')
@@ -329,6 +351,7 @@ class DoubleMLData:
         else:
             self._z_cols = None
         if reset_value:
+            self._check_disjoint_sets()
             self._set_y_z()
 
     @property
@@ -368,6 +391,8 @@ class DoubleMLData:
             raise ValueError('Invalid treatment_var. '
                              f'{treatment_var} is not in d_cols.')
         if self.use_other_treat_as_covariate:
+            # note that the following line needs to be adapted in case an intersection of x_cols and d_cols as allowed
+            # (see https://github.com/DoubleML/doubleml-for-py/issues/83)
             xd_list = self.x_cols + self.d_cols
             xd_list.remove(treatment_var)
         else:
@@ -383,3 +408,32 @@ class DoubleMLData:
             zero_one_treat = np.all((np.power(this_d, 2) - this_d) == 0)
             is_binary[treatment_var] = (binary_treat & zero_one_treat)
         return is_binary
+
+    def _check_disjoint_sets(self):
+        y_col_set = {self.y_col}
+        x_cols_set = set(self.x_cols)
+        d_cols_set = set(self.d_cols)
+
+        if not y_col_set.isdisjoint(x_cols_set):
+            raise ValueError(f'{str(self.y_col)} cannot be set as outcome variable ``y_col`` and covariate in '
+                             '``x_cols``.')
+        if not y_col_set.isdisjoint(d_cols_set):
+            raise ValueError(f'{str(self.y_col)} cannot be set as outcome variable ``y_col`` and treatment variable in '
+                             '``d_cols``.')
+        # note that the line xd_list = self.x_cols + self.d_cols in method set_x_d needs adaption if an intersection of
+        # x_cols and d_cols as allowed (see https://github.com/DoubleML/doubleml-for-py/issues/83)
+        if not d_cols_set.isdisjoint(x_cols_set):
+            raise ValueError('At least one variable/column is set as treatment variable (``d_cols``) and as covariate'
+                             '(``x_cols``). Consider using parameter ``use_other_treat_as_covariate``.')
+
+        if self.z_cols is not None:
+            z_cols_set = set(self.z_cols)
+            if not y_col_set.isdisjoint(z_cols_set):
+                raise ValueError(f'{str(self.y_col)} cannot be set as outcome variable ``y_col`` and instrumental '
+                                 'variable in ``z_cols``.')
+            if not d_cols_set.isdisjoint(z_cols_set):
+                raise ValueError('At least one variable/column is set as treatment variable (``d_cols``) and '
+                                 'instrumental variable in ``z_cols``.')
+            if not x_cols_set.isdisjoint(z_cols_set):
+                raise ValueError('At least one variable/column is set as covariate (``x_cols``) and instrumental '
+                                 'variable in ``z_cols``.')
